@@ -3,16 +3,16 @@
 use strict;
 use warnings;
 
-use lib qw{blib/lib};
+use lib qw<blib/lib>;
 
 use Regexp::Wildcards;
 use Data::Dumper;
 
 my $rw = Regexp::Wildcards->new(
- do      => [ qw/brackets/ ],
- capture => [ qw/single/ ],
+ do      => [ qw<brackets> ],
+ capture => [ qw<single> ],
 );
-$rw->do(add => [ qw/jokers/ ]);
-$rw->capture(add => [ qw/brackets any greedy/ ]);
+$rw->do(add => [ qw<jokers> ]);
+$rw->capture(add => [ qw<brackets any greedy> ]);
 
 print $_, ' => ', $rw->convert($_), "\n" for @ARGV;
